package cases

import (
	"spaceofcheng/services/models"
	"spaceofcheng/services/models/goods"
	"spaceofcheng/services/models/model"
	"spaceofcheng/services/utils"
	"strconv"
	"strings"
	"time"
)

// CaseRecord 月订单记录
type CaseRecord struct {
	model.SysCaseRecord `xorm:"extends"`
	ActrualNum          int
	OverNum             int
	LeftNum             int
}

// GetCaseRecord 获取案场月记录
func (m *CaseDAO) GetCaseRecord(caseids string, page, pageSize int) ([]CaseRecord, error) {
	var records []CaseRecord
	sql := `select * from sys_case_record where case_id in ('` + strings.Replace(caseids, ",", "','", -1) + `') and status>` + strconv.Itoa(models.STATUS_DEL) + ` order by create_date desc limit ` + strconv.Itoa((page-1)*pageSize) + `, ` + strconv.Itoa(pageSize)

	err := m.db.Sql(sql).Find(&records)
	if err != nil {
		return nil, err
	}
	for inx, record := range records {
		orders := new(model.TaGoodsOrders)
		total, err := m.db.Where("case_id=?", record.CaseId).And("status=?", models.STATUS_NORMAL).And("user_type=?", goods.USERTPE_SALES).And("date_format(create_date,'%Y-%m')=?", record.Month).Sums(orders, "orders_num")
		if err != nil {
			return nil, err
		}
		records[inx].ActrualNum = int(total[0])
		var overnum int
		var leftnum int
		if records[inx].ActrualNum > record.Num {
			overnum = records[inx].ActrualNum - record.Num
		} else {
			leftnum = record.Num - records[inx].ActrualNum
		}
		records[inx].OverNum = overnum
		records[inx].LeftNum = leftnum
	}

	return records, err
}

// GetCaseRecordCount 获取月记录
func (m *CaseDAO) GetCaseRecordCount(caseids string) (int, error) {
	var records []CaseRecord
	sql := `select * from sys_case_record where case_id in ('` + strings.Replace(caseids, ",", "','", -1) + `') and status>` + strconv.Itoa(models.STATUS_DEL)

	err := m.db.Sql(sql).Find(&records)
	if err != nil {
		return 0, err
	}
	return len(records), nil
}

// AddRecord 新增案场月记录信息
func (m *CaseDAO) AddRecord(record model.SysCaseRecord) (*model.SysCaseRecord, error) {
	record.CreateDate = time.Now()
	record.RecordId = utils.GetGUID()
	record.Status = models.STATUS_NORMAL
	record.IsOver = 1
	_, err := m.db.Insert(record)
	return &record, err
}

// GetRecordByMonth 根据月份获取月记录信息
func (m *CaseDAO) GetRecordByMonth(caseid, month string) (*model.SysCaseRecord, error) {
	var record []model.SysCaseRecord
	sql := `select * from sys_case_record where case_id=? and status=? and month=?`
	err := m.db.Sql(sql, caseid, models.STATUS_NORMAL, month).Find(&record)

	if err != nil {
		return nil, err
	}
	if len(record) > 0 {
		return &record[0], nil
	}
	return nil, nil
}
