package gymcard

import (
	"spaceofcheng/services/models"
	"spaceofcheng/services/models/model"
	"spaceofcheng/services/utils"
	"strconv"
	"strings"
	"time"

	"github.com/go-xorm/xorm"
)

// GymcardDAO 当前数据库操作对象
type GymcardDAO struct {
	ctx *utils.Context
	db  *xorm.Session
}

// NewGymcardDAO New Inst
func NewGymcardDAO(ctx *utils.Context) *GymcardDAO {
	return &GymcardDAO{
		ctx: ctx,
		db:  ctx.DB,
	}
}
func (m *GymcardDAO) GetGymcard(caseid string, page, pageSize int) ([]model.TaGymCard, error) {
	var gymcard []model.TaGymCard
	sql := `select a.* from ta_gym_card a
	where a.case_id in('` + strings.Replace(caseid, ",", "','", -1) + `')
	and  a.status > ` + strconv.Itoa(models.STATUS_DEL)
	sql += ` order by a.create_date desc limit ` + strconv.Itoa((page-1)*pageSize) + `, ` + strconv.Itoa(pageSize)
	err := m.db.Sql(sql).Find(&gymcard)
	return gymcard, err
}

func (m *GymcardDAO) GetGymcardById(gymcardId string) (*model.TaGymCard, error) {
	var gymcard []model.TaGymCard
	err := m.db.Where("gym_card_id=?", gymcardId).And("status > ?", models.STATUS_DEL).Find(&gymcard)
	if err != nil {
		return nil, err
	}
	if len(gymcard) > 0 {
		return &gymcard[0], nil
	}
	return nil, nil
}

func (m *GymcardDAO) AddGymCard(gymcard model.TaGymCard) (*model.TaGymCard, error) {
	gymcard.GymCardId = utils.GetGUID()
	gymcard.SentCount = 0
	gymcard.UsedCount = 0
	gymcard.Status = models.STATUS_NORMAL
	gymcard.CreateDate = time.Now()
	_, err := m.db.Insert(gymcard)
	return &gymcard, err
}

func (m *GymcardDAO) DeleteGymcard(gymcardId string) error {
	var gymcard = model.TaGymCard{
		GymCardId: gymcardId,
		Status:    models.STATUS_DEL,
	}
	var cols = []string{
		"status",
	}
	_, err := m.db.Cols(cols...).Where("gym_card_id = ?", gymcard.GymCardId).Update(gymcard)
	return err
}

func (m *GymcardDAO) DeleteCardImg(gymcardId string) error {
	var cardImg = model.TaCardImage{
		GymCardId: gymcardId,
		Status:    models.STATUS_DEL,
	}
	var cols = []string{
		"status",
	}
	_, err := m.db.Cols(cols...).Where("gym_card_id = ?", cardImg.GymCardId).Update(cardImg)
	return err

}
